"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.writeFile = writeFile;
exports.readFile = readFile;
exports.stat = stat;
exports.unlink = unlink;
exports.readdir = readdir;
exports.ensuredir = ensuredir;
exports.readdirRecursive = readdirRecursive;
exports.rmRecursive = rmRecursive;

var _fs = require("fs");

var _path = require("path");

function isNotFound(err) {
  return err.code === "ENOENT" || err.code === "EISDIR";
}

async function writeFile(path, data) {
  await ensuredir((0, _path.dirname)(path));
  return _fs.promises.writeFile(path, data, "utf8");
}

function readFile(path) {
  return _fs.promises.readFile(path, "utf8").catch(err => isNotFound(err) ? null : Promise.reject(err));
}

function stat(path) {
  return _fs.promises.stat(path).catch(err => isNotFound(err) ? null : Promise.reject(err));
}

function unlink(path) {
  return _fs.promises.unlink(path).catch(err => isNotFound(err) ? void 0 : Promise.reject(err));
}

function readdir(dir) {
  return _fs.promises.readdir(dir, {
    withFileTypes: true
  }).catch(err => isNotFound(err) ? [] : Promise.reject(err));
}

async function ensuredir(dir) {
  const _stat = await stat(dir);

  if (_stat && _stat.isDirectory()) {
    return;
  }

  await ensuredir((0, _path.dirname)(dir));
  await _fs.promises.mkdir(dir);
}

async function readdirRecursive(dir, ignore) {
  if (ignore && ignore(dir)) {
    return [];
  }

  const entries = await readdir(dir);
  const files = [];
  await Promise.all(entries.map(async entry => {
    const entryPath = (0, _path.resolve)(dir, entry.name);

    if (entry.isDirectory()) {
      const dirFiles = await readdirRecursive(entryPath, ignore);
      files.push(...dirFiles.map(f => entry.name + "/" + f));
    } else {
      if (ignore && !ignore(entry.name)) {
        files.push(entry.name);
      }
    }
  }));
  return files;
}

async function rmRecursive(dir) {
  const entries = await readdir(dir);
  await Promise.all(entries.map(entry => {
    const entryPath = (0, _path.resolve)(dir, entry.name);

    if (entry.isDirectory()) {
      return rmRecursive(entryPath).then(() => _fs.promises.rmdir(entryPath));
    } else {
      return _fs.promises.unlink(entryPath);
    }
  }));
}